# 
# Blackhole slave disabled tests
#
rpl000013 : BHS incompatible test
rpl000017 : BHS incompatible test
rpl_000015 : BHS incompatible test
rpl_EE_err : BHS incompatible test
rpl_auto_increment : BHS incompatible test
rpl_auto_increment_update_failure : BHS incompatible test
rpl_begin_commit_rollback : BHS incompatible test
rpl_binlog_auto_inc_bug33029 : BHS incompatible test
rpl_change_master : BHS incompatible test
rpl_circular_for_4_hosts : BHS incompatible test
rpl_colSize : BHS incompatible test
rpl_commit_after_flush : BHS incompatible test
rpl_concurrency_error : BHS incompatible test
rpl_create_if_not_exists : BHS incompatible test
rpl_create_tmp_table_if_not_exists : BHS incompatible test
rpl_cross_version : BHS incompatible test
rpl_deadlock_innodb : BHS incompatible test
rpl_do_grant : BHS incompatible test
rpl_dual_pos_advance : BHS incompatible test
rpl_err_ignoredtable : BHS incompatible test
rpl_events : BHS incompatible test
rpl_extraCol_innodb : BHS incompatible test
rpl_extraCol_myisam : BHS incompatible test
rpl_extraColmaster_innodb : BHS incompatible test
rpl_extraColmaster_myisam : BHS incompatible test
rpl_filter_tables_not_exist : BHS incompatible test
rpl_flush_logs : BHS incompatible test
rpl_flushlog_loop : BHS incompatible test
rpl_foreign_key_innodb : BHS incompatible test
rpl_geometry : BHS incompatible test
rpl_get_lock : BHS incompatible test
rpl_grant : BHS incompatible test
rpl_heartbeat : BHS incompatible test
rpl_heartbeat_2slaves : BHS incompatible test
rpl_heartbeat_basic : BHS incompatible test
rpl_heartbeat_ssl : BHS incompatible test
rpl_ignore_grant : BHS incompatible test
rpl_ignore_table_update : BHS incompatible test
rpl_innodb_bug28430 : BHS incompatible test
rpl_innodb_bug30888 : BHS incompatible test
rpl_insert : BHS incompatible test
rpl_insert_id : BHS incompatible test
rpl_insert_id_pk : BHS incompatible test
rpl_ip_mix : BHS incompatible test
rpl_ip_mix2 : BHS incompatible test
rpl_ipv4_as_ipv6 : BHS incompatible test
rpl_ipv6 : BHS incompatible test
rpl_loaddata : BHS incompatible test
rpl_loaddata_charset : BHS incompatible test
rpl_loaddata_map : BHS incompatible test
rpl_loaddatalocal : BHS incompatible test
rpl_loadfile : BHS incompatible test
rpl_log_pos : BHS incompatible test
rpl_manual_change_index_file : BHS incompatible test
rpl_master_pos_wait : BHS incompatible test
rpl_mixed_binlog_max_cache_size : BHS incompatible test
rpl_mixed_ddl_dml : BHS incompatible test
rpl_mixed_mixing_engines : BHS incompatible test
rpl_mixed_row_innodb : BHS incompatible test
rpl_multi_delete : BHS incompatible test
rpl_multi_delete2 : BHS incompatible test
rpl_multi_engine : BHS incompatible test
rpl_multi_update : BHS incompatible test
rpl_multi_update2 : BHS incompatible test
rpl_mysql_upgrade : BHS incompatible test
rpl_non_direct_mixed_mixing_engines : BHS incompatible test
rpl_non_direct_row_mixing_engines : BHS incompatible test
rpl_non_direct_stm_mixing_engines : BHS incompatible test
rpl_not_null_innodb : BHS incompatible test
rpl_not_null_myisam : BHS incompatible test
rpl_optimize : BHS incompatible test
rpl_packet : BHS incompatible test
rpl_plugin_load : BHS incompatible test
rpl_rbr_to_sbr : BHS incompatible test
rpl_relayrotate : BHS incompatible test
rpl_relayspace : BHS incompatible test
rpl_replicate_do : BHS incompatible test
rpl_rewrt_db : BHS incompatible test
rpl_rotate_logs : BHS incompatible test
rpl_row_001 : BHS incompatible test
rpl_row_UUID : BHS incompatible test
rpl_row_basic_11bugs : BHS incompatible test
rpl_row_basic_2myisam : BHS incompatible test
rpl_row_basic_3innodb : BHS incompatible test
rpl_row_basic_8partition : BHS incompatible test
rpl_row_binlog_max_cache_size : BHS incompatible test
rpl_row_blob_innodb : BHS incompatible test
rpl_row_blob_myisam : BHS incompatible test
rpl_row_colSize : BHS incompatible test
rpl_row_conflicts : BHS incompatible test
rpl_row_disabled_slave_key : BHS incompatible test
rpl_row_event_max_size : BHS incompatible test
rpl_row_find_row : BHS incompatible test
rpl_row_idempotency : BHS incompatible test
rpl_row_loaddata_concurrent : BHS incompatible test
rpl_row_log : BHS incompatible test
rpl_row_log_innodb : BHS incompatible test
rpl_row_max_relay_size : BHS incompatible test
rpl_row_mixing_engines : BHS incompatible test
rpl_row_mysqlbinlog : BHS incompatible test
rpl_row_rec_comp_innodb : BHS incompatible test
rpl_row_rec_comp_myisam : BHS incompatible test
rpl_row_reset_slave : BHS incompatible test
rpl_row_show_relaylog_events : BHS incompatible test
rpl_row_sp002_innodb : BHS incompatible test
rpl_row_sp005 : BHS incompatible test
rpl_row_sp007_innodb : BHS incompatible test
rpl_row_sp012 : BHS incompatible test
rpl_row_tabledefs_2myisam : BHS incompatible test
rpl_row_tabledefs_3innodb : BHS incompatible test
rpl_row_tbl_metadata : BHS incompatible test
rpl_row_trunc_temp : BHS incompatible test
rpl_row_until : BHS incompatible test
rpl_row_utf32 : BHS incompatible test
rpl_semi_sync : BHS incompatible test
rpl_server_id2 : BHS incompatible test
rpl_server_id_ignore : BHS incompatible test
rpl_set_null_innodb : BHS incompatible test
rpl_set_null_myisam : BHS incompatible test
rpl_show_slave_hosts : BHS incompatible test
rpl_skip_error : BHS incompatible test
rpl_slave_skip : BHS incompatible test
rpl_slow_query_log : BHS incompatible test
rpl_sp : BHS incompatible test
rpl_ssl : BHS incompatible test
rpl_ssl1 : BHS incompatible test
rpl_stm_000001 : BHS incompatible test
rpl_stm_EE_err2 : BHS incompatible test
rpl_stm_binlog_max_cache_size : BHS incompatible test
rpl_stm_conflicts : BHS incompatible test
rpl_stm_flsh_tbls : BHS incompatible test
rpl_stm_innodb : BHS incompatible test
rpl_stm_insert_delayed : BHS incompatible test
rpl_stm_loaddata_concurrent : BHS incompatible test
rpl_stm_log : BHS incompatible test
rpl_stm_max_relay_size : BHS incompatible test
rpl_stm_mix_show_relaylog_events : BHS incompatible test
rpl_stm_mixing_engines : BHS incompatible test
rpl_stm_reset_slave : BHS incompatible test
rpl_stm_sql_mode : BHS incompatible test
rpl_stm_start_stop_slave : BHS incompatible test
rpl_stm_until : BHS incompatible test
rpl_stm_user_variables : BHS incompatible test
rpl_switch_stm_row_mixed : BHS incompatible test
rpl_temp_table : BHS incompatible test
rpl_temp_table_mix_row : BHS incompatible test
rpl_temporary : BHS incompatible test
rpl_temporary_errors : BHS incompatible test
rpl_timezone : BHS incompatible test
rpl_tmp_table_and_DDL : BHS incompatible test
rpl_trigger : BHS incompatible test
rpl_truncate_2myisam : BHS incompatible test
rpl_truncate_3innodb : BHS incompatible test
rpl_typeconv : BHS incompatible test
rpl_typeconv_innodb : BHS incompatible test
rpl_udf : BHS incompatible test
rpl_variables : BHS incompatible test
