eval CREATE TABLE $TABLENAME 
(a INT NOT NULL,
 b varchar (64),
 INDEX ind_$TABLENAME (b,a),
 PRIMARY KEY (a))
ENGINE = $ENGINE
PARTITION BY RANGE (a)
SUBPARTITION BY HASH (a) SUBPARTITIONS 3
(PARTITION pNeg VALUES LESS THAN (0)
 (SUBPARTITION subp0 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp1 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp2 $DATA_PATH $INDEX_PATH),
 PARTITION `p0-29` VALUES LESS THAN (30)
 (SUBPARTITION subp3 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp4 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp5 $DATA_PATH $INDEX_PATH),
 PARTITION `p30-299` VALUES LESS THAN (300)
 (SUBPARTITION subp6 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp7 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp8 $DATA_PATH $INDEX_PATH),
 PARTITION `p300-2999` VALUES LESS THAN (3000)
 (SUBPARTITION subp9 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp10 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp11 $DATA_PATH $INDEX_PATH),
 PARTITION `p3000-299999` VALUES LESS THAN (300000)
 (SUBPARTITION subp12 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp13 $DATA_PATH $INDEX_PATH,
  SUBPARTITION subp14 $DATA_PATH $INDEX_PATH));

#eval SHOW CREATE TABLE $TABLENAME;

