##############################################################################
#
#  List the test cases that are to be disabled temporarily.
#
#  Separate the test case name and the comment with ':'.
#
#    <testcasename> : BUG#<xxxx> <date disabled> <disabler> <comment>
#
#  Do not use any TAB characters for whitespace.
#
##############################################################################
ndb_partition_error2 : Bug#40989 ndb_partition_error2 needs maintenance

# the below testcase have been reworked to avoid the bug, test contains comment, keep bug open
ndb_cache_trans           : Bug#42197 Query cache and autocommit
ndb_disconnect_ddl        : Bug#31853 flaky testcase...

ndb_dbug_lock : SEAGULL gsl locking order
ndb_insert : Bug#16021097 INSERT .. SELECT WITH KEY VIOLATION DOES NOT FAIL
ndb_row_count : Bug#16021097 INSERT .. SELECT WITH KEY VIOLATION DOES NOT FAIL
ndb_add_partition: Bug #17400320 ALGORITHM= IS NOT SUPPORTED FOR ALTER TABLE WITH <PARTITION_OPTIONS>
ndb_addnode: Bug #17400320 ALGORITHM= IS NOT SUPPORTED FOR ALTER TABLE WITH <PARTITION_OPTIONS>
ndb_addnode_withbinlog: Bug #17400320 ALGORITHM= IS NOT SUPPORTED FOR ALTER TABLE WITH <PARTITION_OPTIONS>
ndb_share: Bug #17400320 ALGORITHM= IS NOT SUPPORTED FOR ALTER TABLE WITH <PARTITION_OPTIONS>
ndb_fk_addnode: Bug #17400320 ALGORITHM= IS NOT SUPPORTED FOR ALTER TABLE WITH <PARTITION_OPTIONS>
