# suite/funcs_1/include/cleanup.inc
#
# Remove all objects created by sourcing
# suite/funcs_1/datadict/datadict_load.inc
#
DROP DATABASE test1;
DROP DATABASE test4;
DROP TABLE test.t1;
DROP TABLE test.t2;
DROP TABLE test.t3;
DROP TABLE test.t4;
DROP TABLE test.t7;
DROP TABLE test.t8;
DROP TABLE test.t9;
DROP TABLE test.t10;
DROP TABLE test.t11;
DROP TABLE test.tb1;
DROP TABLE test.tb2;
DROP TABLE test.tb3;
DROP TABLE test.tb4;

