--disable_query_log

delete from t1sum;

insert into t1sum select 0, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2054' and '2090';
insert into t1sum select 1, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1985-10-01 22:43:04.84207' and '1988-05-19 20:13:50.656129';
insert into t1sum select 2, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-08:36:56' and '01:58:00.3';
insert into t1sum select 3, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2008' and '2102';
insert into t1sum select 4, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2089-12-11' and '2096-12-10';
insert into t1sum select 5, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-18:03:40' and '00:38:52.1';
insert into t1sum select 6, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2000-04-11 05:47:32' and '2012-05-12 10:51:47.8';
insert into t1sum select 7, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1995-09-14 21:18:09.459736' and '2001-12-07 04:53:22.239569';
insert into t1sum select 8, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '6191-03-09 09:58:12.195603' and '6605-03-02 01:35:07.7317';
insert into t1sum select 9, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2013-01-13 05:47:22' and '2038-01-19 03:14:07.16';
insert into t1sum select 10, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '17:49:42.2251' and '22:23:27';
insert into t1sum select 11, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1965-03-24 17:11:19.36753' and '8410-07-24 18:56:10.3';
insert into t1sum select 12, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1938-12-27' and '9695-08-08';
insert into t1sum select 13, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2020-03-05 15:14:25.851' and '2032-05-05 03:37:59.4142';
insert into t1sum select 14, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2022-03-16' and '2058-08-05';
insert into t1sum select 15, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-00:00:59.35835' and '00:21:13';
insert into t1sum select 16, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-09-21 16:09:25.603458' and '2028-04-14 17:56:38.6';
insert into t1sum select 17, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2020-08-13 14:17:37.422362' and '2015-06-01 20:24:54.85';
insert into t1sum select 18, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-18:09:34' and '-19:49:27.46';
insert into t1sum select 19, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1955' and '2111';
insert into t1sum select 20, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-13:18:30.47' and '-18:07:46.140420';
insert into t1sum select 21, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-02:56:52.999' and '22:42:04.17219';
insert into t1sum select 22, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2019-12-24 11:35:16.75' and '2035-03-25 19:34:19.647930';
insert into t1sum select 23, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2917-01-11' and '2016-08-20';
insert into t1sum select 24, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1900-04-26 16:30:16.53' and '2027-08-12 02:08:18.79451';
insert into t1sum select 25, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2015' and '2109';
insert into t1sum select 26, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-09:13:31.38' and '-13:57:47.12469';
insert into t1sum select 27, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1981-04-19 23:44:51' and '2012-09-04 15:54:34.80278';
insert into t1sum select 28, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1985-07-16 05:25:19.8883' and '2011-08-08 10:28:37.603';
insert into t1sum select 29, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1903' and '1990';
insert into t1sum select 30, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1996-11-03' and '2077-11-01';
insert into t1sum select 31, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1917-05-24' and '1950-07-16';
insert into t1sum select 32, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1973-04-28' and '2026-07-14';
insert into t1sum select 33, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1933' and '2052';
insert into t1sum select 34, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2026-12-13 18:49:27.528672' and '1977-01-29 22:07:26.51';
insert into t1sum select 35, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-05:00:04' and '-18:27:14.185';
insert into t1sum select 36, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-01-22 04:43:44' and '2031-11-24 14:57:25.3896';
insert into t1sum select 37, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-06:57:09.3' and '04:58:30';
insert into t1sum select 38, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1978-04-01 20:12:00.203' and '2015-02-14 08:38:33.108';
insert into t1sum select 39, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-16:20:12' and '21:51:42';
insert into t1sum select 40, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2000-01-06 09:33:08.6' and '2026-05-31 11:40:55.33678';
insert into t1sum select 41, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2039' and '2048';
insert into t1sum select 42, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2011-10-07 18:46:08.405' and '8872-05-13 07:50:16.572344';
insert into t1sum select 43, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1945-02-11 19:13:42.9' and '1954-06-30 02:34:30.41';
insert into t1sum select 44, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1991-09-01' and '2020-09-09';
insert into t1sum select 45, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1992-02-18 02:43:51' and '2031-09-22 23:19:03.77';
insert into t1sum select 46, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1944-05-03 06:04:12.578191' and '1966-07-28 14:44:11.87';
insert into t1sum select 47, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1979-04-16 21:32:54.97' and '2100-06-28 20:33:27.685114';
insert into t1sum select 48, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1946-04-01' and '2007-12-25';
insert into t1sum select 49, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2012-02-13' and '2017-01-02';
insert into t1sum select 50, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1286-05-07' and '2051-08-31';
insert into t1sum select 51, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1948-08-09 04:30:52.138185' and '2058-06-08 10:00:20.81';
insert into t1sum select 52, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2087-04-02 23:07:46' and '3062-09-23 13:54:11.6';
insert into t1sum select 53, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1945-06-04 12:08:15.768184' and '2076-04-19 12:18:30.26611';
insert into t1sum select 54, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1903-11-14 14:28:18.856' and '2044-09-19 05:32:57.33470';
insert into t1sum select 55, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1955-04-16' and '2086-07-14';
insert into t1sum select 56, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-00:07:27.534192' and '-00:56:25';
insert into t1sum select 57, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1906-07-11 04:55:50' and '1974-01-19 10:11:48';
insert into t1sum select 58, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2018-12-12 04:48:05' and '2077-05-23 19:23:02.9';
insert into t1sum select 59, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2008-02-06' and '1983-01-19';
insert into t1sum select 60, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1987-02-25 06:57:14' and '1996-07-20 19:25:00.4';
insert into t1sum select 61, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2088' and '2155';
insert into t1sum select 62, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1916-09-18 11:10:34.72' and '1953-08-04 09:20:00';
insert into t1sum select 63, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1942-09-13' and '2057-01-18';
insert into t1sum select 64, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1995-02-21 06:48:20.14' and '2002-11-01 12:17:21.19';
insert into t1sum select 65, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2070-04-01 08:09:05.46' and '2013-04-30 16:55:25';
insert into t1sum select 66, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1968-02-26 12:54:17.7214' and '2087-10-08 10:17:18.305';
insert into t1sum select 67, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2018' and '2108';
insert into t1sum select 68, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1900-01-17' and '2025-09-04';
insert into t1sum select 69, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-13:19:57.406' and '19:43:56.946876';
insert into t1sum select 70, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2009-10-23' and '2084-12-31';
insert into t1sum select 71, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2031' and '2122';
insert into t1sum select 72, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-194:24:40.7' and '23:41:58';
insert into t1sum select 73, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '9862-05-31' and '2019-11-27';
insert into t1sum select 74, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2096-04-20' and '2095-10-15';
insert into t1sum select 75, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '1954';
insert into t1sum select 76, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-01:57:36' and '18:36:08.3676';
insert into t1sum select 77, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1936-02-23 18:03:38.211405' and '2099-03-06 09:44:11.42638';
insert into t1sum select 78, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2016-12-03 23:03:38.50' and '2022-05-19 10:40:40';
insert into t1sum select 79, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1991-01-12 11:33:28.977' and '1971-06-05 07:07:23';
insert into t1sum select 80, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-09-17 02:33:00' and '2028-05-26 11:45:39.383579';
insert into t1sum select 81, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '2155';
insert into t1sum select 82, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1977-12-21 22:24:59.339385' and '1977-08-24 23:04:45.480018';
insert into t1sum select 83, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '06:21:38.6383' and '10:29:18.2';
insert into t1sum select 84, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-12-07 10:46:19.31692' and '1973-01-15 06:11:25';
insert into t1sum select 85, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '08:23:09.9599' and '13:49:23.287104';
insert into t1sum select 86, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-22:34:36.7' and '01:57:35.81';
insert into t1sum select 87, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1944' and '1966';
insert into t1sum select 88, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1961-05-09' and '2084-05-16';
insert into t1sum select 89, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1961' and '1984';
insert into t1sum select 90, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2055-12-16' and '2013-07-16';
insert into t1sum select 91, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-14:48:06' and '00:47:18.790';
insert into t1sum select 92, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1929-12-08' and '1960-04-08';
insert into t1sum select 93, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '08:07:07.2650' and '-15:12:59.11338';
insert into t1sum select 94, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1922-09-24 11:35:05' and '2006-08-25 05:48:51.5659';
insert into t1sum select 95, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1903-01-21 13:12:46' and '2020-07-26 12:35:51.56156';
insert into t1sum select 96, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2026' and '2062';
insert into t1sum select 97, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1965-06-07 04:37:25.8' and '2001-07-02 02:01:52';
insert into t1sum select 98, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2155' and '2073';
insert into t1sum select 99, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1900-10-03' and '8969-01-27';
insert into t1sum select 100, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1978-01-03 15:53:24' and '2003-03-19 01:31:37.6';
insert into t1sum select 101, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1928-10-27' and '2001-01-27';
insert into t1sum select 102, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2012-10-01 08:01:14.6267' and '2010-07-28 01:31:09.188691';
insert into t1sum select 103, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1911' and '1951';
insert into t1sum select 104, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1922' and '2040';
insert into t1sum select 105, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '12:39:59.9160' and '-06:00:02.7335';
insert into t1sum select 106, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2075-07-31 14:52:59.46' and '1900-02-01 00:40:32.12573';
insert into t1sum select 107, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-10:01:00' and '20:43:54.986015';
insert into t1sum select 108, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-14:00:46.854258' and '14:30:21.74';
insert into t1sum select 109, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1900-07-28 06:49:37.948' and '3726-07-19 10:47:37.4';
insert into t1sum select 110, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2007' and '2121';
insert into t1sum select 111, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1914-06-09 07:56:08.1217' and '2096-11-28 02:20:26.2879';
insert into t1sum select 112, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2005-04-23' and '1925-11-28';
insert into t1sum select 113, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1942-09-17 06:46:50.1444' and '1956-12-29 14:26:33.99';
insert into t1sum select 114, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1983-02-03 18:03:19.857' and '2023-11-04 01:10:39';
insert into t1sum select 115, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1955' and '2129';
insert into t1sum select 116, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2059-07-24 23:59:32.886' and '2068-01-31 03:44:58.1197';
insert into t1sum select 117, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2033-07-25 04:01:42.5481' and '5038-01-02 22:49:23.522661';
insert into t1sum select 118, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1924-02-26 08:24:30.10' and '3648-03-06 12:49:38';
insert into t1sum select 119, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-12-24 02:14:40.52' and '2035-01-16 05:36:05.94723';
insert into t1sum select 120, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1941-12-28 00:14:40' and '5813-10-21 00:23:33.99999';
insert into t1sum select 121, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2009-12-25' and '2054-02-05';
insert into t1sum select 122, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1900-06-17' and '2056-08-15';
insert into t1sum select 123, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2023-04-22 15:44:17.493603' and '1974-06-26 08:47:30.43339';
insert into t1sum select 124, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2095' and '2142';
insert into t1sum select 125, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1984-06-29 23:45:58.3' and '1988-06-11 12:35:29';
insert into t1sum select 126, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2047' and '2154';
insert into t1sum select 127, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1998-10-01 00:34:43.268' and '2018-04-14 02:57:07';
insert into t1sum select 128, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1925-01-20 13:21:40' and '1997-04-06 23:09:34.4';
insert into t1sum select 129, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1992' and '2048';
insert into t1sum select 130, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2041-10-21' and '3846-04-30';
insert into t1sum select 131, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-07:20:43.625' and '23:12:29.91';
insert into t1sum select 132, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-09:54:05' and '21:57:11.11243';
insert into t1sum select 133, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2038' and '2073';
insert into t1sum select 134, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1977' and '2015';
insert into t1sum select 135, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2036-11-27 22:06:15.3' and '2035-07-28 10:53:32.37597';
insert into t1sum select 136, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2006-11-01 23:25:56.2' and '2023-10-28 12:19:35.356';
insert into t1sum select 137, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-05:46:22.84980' and '-05:44:20.12987';
insert into t1sum select 138, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '1965';
insert into t1sum select 139, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1915-05-29 09:04:07.99' and '3551-12-14 04:17:44';
insert into t1sum select 140, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-12:23:27.5207' and '09:10:42';
insert into t1sum select 141, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-17:30:18.319' and '-22:13:36.2986';
insert into t1sum select 142, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1935-08-23 10:30:00' and '1983-01-20 13:27:54.803';
insert into t1sum select 143, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1986-11-16 01:22:51.43' and '1994-07-11 09:22:26.704';
insert into t1sum select 144, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1944-08-11 22:00:10.484906' and '2100-07-31 16:51:45.3';
insert into t1sum select 145, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1972-12-17 03:44:37.96851' and '2000-03-15 18:17:18';
insert into t1sum select 146, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1947' and '2019';
insert into t1sum select 147, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '1907';
insert into t1sum select 148, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-04:00:27.4' and '-18:46:00';
insert into t1sum select 149, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2029-05-14' and '2040-09-29';
insert into t1sum select 150, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1996' and '2094';
insert into t1sum select 151, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '13:46:43.991' and '371:58:05';
insert into t1sum select 152, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1032-01-12' and '2012-03-17';
insert into t1sum select 153, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1999-06-14 17:59:46' and '2006-05-31 23:11:03';
insert into t1sum select 154, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1986' and '2081';
insert into t1sum select 155, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-03:33:01' and '-23:04:47';
insert into t1sum select 156, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1963-07-25 08:00:21.2' and '1989-07-15 16:00:24';
insert into t1sum select 157, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1905' and '1983';
insert into t1sum select 158, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1975-08-17 23:17:08.59' and '2038-01-19 03:14:07';
insert into t1sum select 159, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1969' and '2078';
insert into t1sum select 160, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2038-02-17 20:14:10.389' and '4849-12-04 07:39:16.5065';
insert into t1sum select 161, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1937' and '1989';
insert into t1sum select 162, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2092-10-03 15:18:23' and '7261-02-20 18:58:20';
insert into t1sum select 163, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1908-04-02' and '2068-07-27';
insert into t1sum select 164, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2035-04-01' and '1910-07-30';
insert into t1sum select 165, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1978-07-26' and '2100-08-13';
insert into t1sum select 166, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-13:58:23.9755' and '06:02:35.139';
insert into t1sum select 167, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1971-10-04 10:37:39.36' and '2030-01-01 03:59:50.960';
insert into t1sum select 168, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1948' and '2044';
insert into t1sum select 169, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1943-02-08 09:29:37.1536' and '2051-05-03 00:17:34.5';
insert into t1sum select 170, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1955-06-24 13:07:54' and '2027-01-01 04:55:43.4182';
insert into t1sum select 171, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2067-09-15' and '7164-09-28';
insert into t1sum select 172, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1959-07-19' and '2068-01-25';
insert into t1sum select 173, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2058-08-14 00:59:40.9' and '8885-11-24 05:20:37';
insert into t1sum select 174, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1939-12-19' and '1951-05-04';
insert into t1sum select 175, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1996-07-31 02:41:22' and '2053-03-16 10:36:35';
insert into t1sum select 176, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2040-06-09' and '2056-05-02';
insert into t1sum select 177, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1964-05-15 08:58:30.362002' and '1997-04-03 18:44:54.75';
insert into t1sum select 178, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-304:56:11.42' and '02:44:58.89096';
insert into t1sum select 179, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1930' and '2119';
insert into t1sum select 180, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2002-11-18 23:04:39.13229' and '2006-02-03 03:59:11.268';
insert into t1sum select 181, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2094-12-26 19:57:59.4908' and '1978-04-09 12:27:14.30110';
insert into t1sum select 182, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '07:19:11.95' and '02:45:01';
insert into t1sum select 183, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1935-07-21' and '2085-04-16';
insert into t1sum select 184, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1951-07-26 08:24:59.3663' and '2062-10-10 01:51:11.41079';
insert into t1sum select 185, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1967-06-16 05:33:00.67' and '2045-09-29 11:39:47.33';
insert into t1sum select 186, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1910-08-11 17:22:29.965038' and '2073-02-02 02:56:04.80271';
insert into t1sum select 187, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2038-12-09' and '1990-10-13';
insert into t1sum select 188, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '01:08:08' and '10:42:13.7';
insert into t1sum select 189, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1952' and '2042';
insert into t1sum select 190, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1997-03-05 21:00:12.9841' and '2026-06-07 13:59:22.4';
insert into t1sum select 191, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2024-11-06 04:25:15.663' and '8066-02-19 08:24:41.32';
insert into t1sum select 192, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1993-02-02 06:32:54.5036' and '2027-08-01 21:22:33.37828';
insert into t1sum select 193, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1914' and '2126';
insert into t1sum select 194, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2081' and '1923';
insert into t1sum select 195, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1907' and '2075';
insert into t1sum select 196, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1975-11-06 00:59:29.51859' and '2023-05-08 17:41:41';
insert into t1sum select 197, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1944-03-01' and '2062-03-25';
insert into t1sum select 198, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2067-05-09 11:30:57.6264' and '2090-05-01 04:40:12.23';
insert into t1sum select 199, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2007-05-05 13:39:58.74331' and '2007-10-16 01:27:41.35194';
insert into t1sum select 200, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2015-04-13 07:15:04.52919' and '2034-02-21 13:14:38.461742';
insert into t1sum select 201, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1901-08-05 15:23:01.78669' and '1993-03-16 00:26:41';
insert into t1sum select 202, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2019-03-30 23:09:42.969' and '2011-09-01 00:08:07';
insert into t1sum select 203, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2003-09-10 23:23:57' and '1975-08-23 21:41:36.8635';
insert into t1sum select 204, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2015' and '2112';
insert into t1sum select 205, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-23:11:20' and '-23:13:55.7';
insert into t1sum select 206, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-08:04:36.79778' and '-21:24:14.27';
insert into t1sum select 207, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1900-03-27' and '2028-12-15';
insert into t1sum select 208, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1972-12-17 08:38:46.972212' and '1973-03-31 17:04:29';
insert into t1sum select 209, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-103:10:33.804' and '16:00:55.7147';
insert into t1sum select 210, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1936' and '2136';
insert into t1sum select 211, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1972' and '2135';
insert into t1sum select 212, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1956-02-03 11:32:57' and '2035-03-21 02:50:59.819';
insert into t1sum select 213, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1988-07-25 23:40:23.41' and '2013-01-11 18:21:23.96';
insert into t1sum select 214, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1982-03-01 13:53:21.1982' and '2036-04-08 08:53:12.58';
insert into t1sum select 215, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1931-03-24 01:11:53' and '3416-03-19 15:44:49';
insert into t1sum select 216, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1948-06-25 01:00:17.61408' and '2027-05-15 18:00:42';
insert into t1sum select 217, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1988-03-28 23:45:39.5' and '2013-10-22 07:05:44.511016';
insert into t1sum select 218, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1941' and '2140';
insert into t1sum select 219, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1906-02-07 15:36:15.606' and '2023-08-17 15:54:03.6';
insert into t1sum select 220, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '4133-08-23' and '5701-11-15';
insert into t1sum select 221, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2005-06-16 23:25:22.7259' and '2005-08-06 03:37:10.5429';
insert into t1sum select 222, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1937' and '2096';
insert into t1sum select 223, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1974-03-16' and '2093-12-09';
insert into t1sum select 224, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1942-03-10' and '2058-11-30';
insert into t1sum select 225, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-12:40:11.29' and '-20:56:35.7';
insert into t1sum select 226, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-10-13 23:24:58.30105' and '1977-11-04 03:22:36.705304';
insert into t1sum select 227, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1998-11-07 04:41:16.83' and '2024-12-25 13:55:57.8';
insert into t1sum select 228, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2037-08-08 14:21:29.74' and '2017-10-19 12:00:45.3488';
insert into t1sum select 229, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1950' and '2046';
insert into t1sum select 230, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1909' and '1939';
insert into t1sum select 231, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2092' and '2065';
insert into t1sum select 232, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1973-07-28 12:17:34.3778' and '1990-02-07 18:29:40.4';
insert into t1sum select 233, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1902-08-04' and '1926-08-01';
insert into t1sum select 234, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1938' and '1958';
insert into t1sum select 235, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '2100';
insert into t1sum select 236, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '7552-10-31 13:45:13.2278' and '1927-12-30 01:27:55.23';
insert into t1sum select 237, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-18:42:23.6' and '-22:01:16.56';
insert into t1sum select 238, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-14:30:01.47996' and '07:06:26.4';
insert into t1sum select 239, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '22:41:37.16' and '17:59:21.838752';
insert into t1sum select 240, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1936' and '2008';
insert into t1sum select 241, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1989' and '2000';
insert into t1sum select 242, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-02:46:19' and '12:25:21.860';
insert into t1sum select 243, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1960-03-14' and '1986-10-24';
insert into t1sum select 244, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2018-07-24 06:20:00.113' and '2006-04-13 12:57:08.94';
insert into t1sum select 245, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1327-01-10 16:45:04.753' and '2065-11-10 12:41:01.1729';
insert into t1sum select 246, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1971-12-06 00:18:22.563' and '2069-03-11 17:58:18.71023';
insert into t1sum select 247, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2025-02-21 16:27:50.905690' and '1980-03-05 23:20:34.6';
insert into t1sum select 248, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1918-12-07' and '1983-12-29';
insert into t1sum select 249, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-06-28 23:07:44' and '1974-11-17 17:00:09.196';
insert into t1sum select 250, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1972' and '2149';
insert into t1sum select 251, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2002-02-07 17:59:26' and '2015-02-12 23:00:24.9';
insert into t1sum select 252, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1957-08-31 05:23:22.8278' and '2020-07-15 00:08:21.58457';
insert into t1sum select 253, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2035-10-16 05:47:01.7' and '2038-01-19 03:14:07.4029';
insert into t1sum select 254, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-16:19:38.81452' and '-18:00:38.8669';
insert into t1sum select 255, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1992-08-22 23:36:51' and '2019-08-14 08:42:59.6106';
insert into t1sum select 256, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1987-10-14 14:44:00.928' and '2018-10-09 20:57:03.71336';
insert into t1sum select 257, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1900-08-20' and '2052-02-18';
insert into t1sum select 258, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1906-01-29' and '1954-08-31';
insert into t1sum select 259, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1997-02-18 11:28:53.9967' and '2021-03-23 01:42:26.37205';
insert into t1sum select 260, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1934' and '2073';
insert into t1sum select 261, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2031-09-24 07:56:02' and '7356-09-25 16:40:51.980571';
insert into t1sum select 262, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1978-05-07 10:52:45.594789' and '1997-06-14 10:03:08.9959';
insert into t1sum select 263, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-00:42:36' and '-07:57:14';
insert into t1sum select 264, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1987-11-15 09:59:13.319' and '2015-04-16 19:46:00.62541';
insert into t1sum select 265, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2016-07-16 02:24:00' and '2020-03-26 05:37:04.44';
insert into t1sum select 266, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1912-07-01 01:34:29.105' and '2087-02-06 04:58:08.454259';
insert into t1sum select 267, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1914-11-20 01:14:47' and '2096-11-02 03:49:21.232';
insert into t1sum select 268, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-02:53:36' and '-23:08:03.64';
insert into t1sum select 269, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1922-07-11' and '2034-07-30';
insert into t1sum select 270, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '04:44:23.751167' and '17:45:11.3';
insert into t1sum select 271, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1900-01-04 15:12:51.274' and '2075-02-28 11:43:41';
insert into t1sum select 272, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1994-03-15 19:14:16' and '2034-06-01 08:33:35';
insert into t1sum select 273, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1978-01-16' and '2079-05-22';
insert into t1sum select 274, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-21:05:36.9150' and '00:20:51.52';
insert into t1sum select 275, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1993' and '2000';
insert into t1sum select 276, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2008-07-20 08:03:59.25' and '2029-07-25 07:49:23';
insert into t1sum select 277, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1930-05-30' and '1991-11-17';
insert into t1sum select 278, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1974-06-02 18:53:04.240' and '2014-06-06 04:12:05';
insert into t1sum select 279, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2092-04-28' and '2100-03-12';
insert into t1sum select 280, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1977-12-26 15:21:21' and '2007-07-26 18:06:00.7';
insert into t1sum select 281, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2125' and '2144';
insert into t1sum select 282, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2083-06-08 21:54:38.59770' and '3823-06-30 01:00:58.7736';
insert into t1sum select 283, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1992-04-09 18:40:27.66' and '2007-12-05 06:44:12.5360';
insert into t1sum select 284, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2003-01-31' and '2041-10-24';
insert into t1sum select 285, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2033-12-18 07:16:20.359' and '2099-07-21 02:55:13.42304';
insert into t1sum select 286, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1916-01-30' and '2040-06-11';
insert into t1sum select 287, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1929-04-11' and '1982-02-19';
insert into t1sum select 288, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2076-12-14 01:06:38.70' and '2099-04-20 16:56:18.5441';
insert into t1sum select 289, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2070-12-31' and '8412-03-30';
insert into t1sum select 290, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2004' and '2151';
insert into t1sum select 291, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2008-12-04 19:52:30' and '2028-06-11 11:49:50.5';
insert into t1sum select 292, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1972-01-22 21:38:58.944' and '1981-06-30 16:01:11.823';
insert into t1sum select 293, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-23:38:33.239' and '-536:07:13.949';
insert into t1sum select 294, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2020-03-07 06:57:14.80911' and '2023-08-10 04:06:19';
insert into t1sum select 295, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1932-02-07' and '2043-04-12';
insert into t1sum select 296, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1981' and '2053';
insert into t1sum select 297, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1921-01-12' and '1928-12-31';
insert into t1sum select 298, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-11:50:08.9' and '-20:04:55.62';
insert into t1sum select 299, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1902' and '2054';
insert into t1sum select 300, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2072-12-16' and '9404-07-24';
insert into t1sum select 301, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1970-01-26 12:51:43.2' and '1981-07-04 00:24:15';
insert into t1sum select 302, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1997-01-12 09:22:12.6' and '2038-01-19 03:14:07.9';
insert into t1sum select 303, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1969-11-19 07:50:22.70' and '2074-02-08 04:23:06.56224';
insert into t1sum select 304, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2028' and '2056';
insert into t1sum select 305, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2022-05-19 17:03:37' and '2034-01-11 16:55:04';
insert into t1sum select 306, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2015' and '2118';
insert into t1sum select 307, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2000-09-25' and '2038-05-18';
insert into t1sum select 308, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '06:29:59.70139' and '19:18:54';
insert into t1sum select 309, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2075' and '1978';
insert into t1sum select 310, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2019-01-18' and '2027-10-26';
insert into t1sum select 311, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2099-12-05 05:15:59' and '2022-10-07 08:38:01.9';
insert into t1sum select 312, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2135' and '1901';
insert into t1sum select 313, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1921-11-18' and '2082-04-11';
insert into t1sum select 314, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1946' and '1947';
insert into t1sum select 315, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1976-10-18' and '2037-11-08';
insert into t1sum select 316, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2019-04-23 18:48:46.7167' and '2030-01-03 17:48:54.2';
insert into t1sum select 317, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2000' and '2061';
insert into t1sum select 318, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1986-04-10 00:44:50.39' and '2037-04-27 07:15:34.3801';
insert into t1sum select 319, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-13:40:36.5515' and '16:55:14';
insert into t1sum select 320, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-02-03 03:52:31.5' and '1997-10-30 21:38:43.70986';
insert into t1sum select 321, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1975-04-08 21:47:47.370' and '2026-07-17 07:11:10.715';
insert into t1sum select 322, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-23:38:19.520' and '646:29:32.13';
insert into t1sum select 323, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1947' and '2039';
insert into t1sum select 324, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1999' and '2046';
insert into t1sum select 325, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1977-02-15 23:45:20.9' and '1984-02-10 23:53:22.97';
insert into t1sum select 326, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2142' and '2151';
insert into t1sum select 327, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1936-03-27' and '2099-03-26';
insert into t1sum select 328, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2060-01-09' and '2008-09-13';
insert into t1sum select 329, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2025-08-26 00:27:19.7' and '2096-10-03 10:55:36.22';
insert into t1sum select 330, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '20:29:19.863245' and '00:26:35.88894';
insert into t1sum select 331, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2110' and '2051';
insert into t1sum select 332, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1973' and '2083';
insert into t1sum select 333, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '23:25:41' and '674:44:46.439';
insert into t1sum select 334, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2032' and '2037';
insert into t1sum select 335, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-04:59:41' and '23:30:23.158';
insert into t1sum select 336, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1908' and '2126';
insert into t1sum select 337, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1946' and '2127';
insert into t1sum select 338, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1923-03-24' and '2100-01-13';
insert into t1sum select 339, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1997-07-19 01:18:42.1358' and '1999-08-05 13:53:00.3953';
insert into t1sum select 340, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2048-08-19 20:45:21.4' and '3201-06-22 03:59:50.97';
insert into t1sum select 341, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2059' and '2072';
insert into t1sum select 342, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1992-09-10' and '5086-12-14';
insert into t1sum select 343, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1924' and '2053';
insert into t1sum select 344, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2001-01-01 23:50:06.55576' and '2093-02-20 03:52:27.55';
insert into t1sum select 345, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2010-11-15 00:39:21.27232' and '2022-01-30 10:59:11.702';
insert into t1sum select 346, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1997-05-31' and '2013-05-30';
insert into t1sum select 347, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '12:50:59.21' and '267:21:34.99';
insert into t1sum select 348, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1904' and '2110';
insert into t1sum select 349, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2045-02-17 12:00:33' and '2066-02-16 15:52:59.68';
insert into t1sum select 350, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2035-04-28' and '2096-08-13';
insert into t1sum select 351, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1996-01-01 10:37:42.4365' and '2038-01-19 03:14:07.5596';
insert into t1sum select 352, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1976-08-23 00:10:26.29574' and '2007-10-07 12:47:21.697';
insert into t1sum select 353, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1829-03-13 17:15:39.216' and '9833-03-08 05:34:12.66884';
insert into t1sum select 354, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2058' and '2068';
insert into t1sum select 355, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-20:06:24.44' and '11:24:54.79891';
insert into t1sum select 356, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1990' and '2003';
insert into t1sum select 357, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2047' and '2090';
insert into t1sum select 358, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1981-03-26 05:01:09.7100' and '2001-12-13 09:34:10.375026';
insert into t1sum select 359, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2004-03-08 04:37:10' and '2034-08-01 22:21:49.748';
insert into t1sum select 360, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2034-07-23' and '1931-02-05';
insert into t1sum select 361, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2053-01-25 21:25:09.66' and '2087-06-06 06:53:19.76';
insert into t1sum select 362, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1986' and '2096';
insert into t1sum select 363, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2076-01-13' and '2060-12-16';
insert into t1sum select 364, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2019' and '2070';
insert into t1sum select 365, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1947-07-16' and '2029-01-14';
insert into t1sum select 366, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2023-02-15 02:06:07.672277' and '2038-01-19 03:14:07.40';
insert into t1sum select 367, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2050' and '2109';
insert into t1sum select 368, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-02-04 22:44:32.726890' and '1981-05-28 03:04:39.84162';
insert into t1sum select 369, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-06:47:01.56477' and '19:43:19.22';
insert into t1sum select 370, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1971-03-27 18:58:18.67' and '2037-07-06 00:50:04.915732';
insert into t1sum select 371, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '08:59:49' and '19:08:01.8864';
insert into t1sum select 372, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1922-06-12' and '2098-11-24';
insert into t1sum select 373, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-11:40:03.3' and '21:25:34.20';
insert into t1sum select 374, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2060' and '2069';
insert into t1sum select 375, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1910' and '2049';
insert into t1sum select 376, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1966' and '2070';
insert into t1sum select 377, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-04-13 07:01:10' and '1982-07-19 02:15:13';
insert into t1sum select 378, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1985-05-11 05:28:49.4872' and '1994-06-10 20:46:22.9';
insert into t1sum select 379, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2012-01-15 19:43:40.49761' and '1982-02-22 18:33:10';
insert into t1sum select 380, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2024-07-18' and '6215-04-01';
insert into t1sum select 381, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-18:39:26.687304' and '-19:17:51.89753';
insert into t1sum select 382, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1982-02-10 14:47:44.17' and '2034-06-28 11:29:15';
insert into t1sum select 383, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1998-07-14 13:16:15' and '1977-02-18 12:33:20.30';
insert into t1sum select 384, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1984-09-09 10:29:08.91980' and '2002-06-04 01:54:40.97443';
insert into t1sum select 385, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1979-12-11 16:15:02.7' and '2030-05-12 23:39:33.99';
insert into t1sum select 386, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2006-04-26 05:01:29.274' and '2064-09-30 16:03:17.692074';
insert into t1sum select 387, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2015-03-17 15:14:06.743476' and '2015-09-10 15:45:58.789';
insert into t1sum select 388, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '12:56:54.664' and '21:35:38.945';
insert into t1sum select 389, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2021-06-17 11:49:26.999999' and '2073-07-27 08:11:33.80059';
insert into t1sum select 390, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2029-09-14 02:58:50.65817' and '1987-05-22 22:41:40.854705';
insert into t1sum select 391, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-00:17:37.6' and '20:08:10.1';
insert into t1sum select 392, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1960-10-01 22:50:20.517' and '2100-08-01 01:06:21.709538';
insert into t1sum select 393, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2044-08-28' and '4555-12-11';
insert into t1sum select 394, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1943' and '2155';
insert into t1sum select 395, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2011-05-12 01:10:04' and '2043-05-17 23:51:34.1';
insert into t1sum select 396, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1973-01-27 16:23:07' and '2038-01-19 03:14:07.5655';
insert into t1sum select 397, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1931-12-05' and '2001-02-27';
insert into t1sum select 398, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-13:51:51.7' and '-23:34:48.36';
insert into t1sum select 399, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-19:18:43.550316' and '-19:42:52.58395';
insert into t1sum select 400, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2001-06-12' and '2024-08-06';
insert into t1sum select 401, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1965-12-23 17:59:09' and '1988-08-15 02:02:45.80';
insert into t1sum select 402, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2088' and '2094';
insert into t1sum select 403, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-09:55:53' and '08:54:37.63';
insert into t1sum select 404, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2080' and '2139';
insert into t1sum select 405, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1981-11-27 05:18:20' and '1997-02-04 06:03:52.337';
insert into t1sum select 406, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1974-05-16 13:11:45.451' and '1976-08-10 20:37:10.6';
insert into t1sum select 407, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2011-04-02' and '9999-10-04';
insert into t1sum select 408, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-03:43:55' and '-08:25:10.2';
insert into t1sum select 409, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1978-08-17 00:58:38.39' and '1995-11-03 23:31:14';
insert into t1sum select 410, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '06:01:36' and '08:37:06.893946';
insert into t1sum select 411, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1946-04-05 18:44:13.35196' and '2047-09-16 08:54:19.6746';
insert into t1sum select 412, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2031-02-23 06:29:15.2' and '1992-07-12 03:53:58.516';
insert into t1sum select 413, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1904' and '2015';
insert into t1sum select 414, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1973-06-03 03:36:39.2834' and '2017-04-13 07:22:18.67';
insert into t1sum select 415, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-04:34:30' and '-04:38:02.86';
insert into t1sum select 416, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1931-10-02 13:38:05.68270' and '2015-04-14 16:37:58';
insert into t1sum select 417, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1933' and '2142';
insert into t1sum select 418, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1994' and '2137';
insert into t1sum select 419, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2029-12-03 02:39:32.394774' and '2030-06-05 21:34:25';
insert into t1sum select 420, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-02:59:10' and '-233:39:53';
insert into t1sum select 421, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2039' and '2128';
insert into t1sum select 422, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1980-04-24 07:11:46' and '2008-03-31 15:03:09';
insert into t1sum select 423, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2060-11-16 22:27:50.507' and '7547-11-27 06:50:11.87340';
insert into t1sum select 424, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1913-02-15' and '2078-08-04';
insert into t1sum select 425, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2002-11-28 07:15:43.16593' and '2003-01-03 06:51:29.77';
insert into t1sum select 426, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2101' and '2018';
insert into t1sum select 427, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1938-06-29' and '1990-08-20';
insert into t1sum select 428, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-139:12:55.213074' and '730:39:19';
insert into t1sum select 429, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2043' and '1902';
insert into t1sum select 430, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1971-08-19 13:15:21.54963' and '8161-10-17 07:17:20.61060';
insert into t1sum select 431, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2000-07-30 00:23:41.27' and '2043-12-20 09:52:06';
insert into t1sum select 432, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2005' and '2029';
insert into t1sum select 433, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1994-12-12 03:21:12' and '2034-03-11 13:02:23.649257';
insert into t1sum select 434, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2064-02-10' and '2078-11-04';
insert into t1sum select 435, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-08-15 15:01:05.2515' and '2007-05-30 11:20:24.73540';
insert into t1sum select 436, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '03:38:59' and '-720:59:10.93826';
insert into t1sum select 437, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1949-06-19 21:52:30.635' and '2026-01-05 19:34:55.5494';
insert into t1sum select 438, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-01:36:17.2825' and '-523:50:28.60';
insert into t1sum select 439, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-03:00:06.673197' and '-07:15:37.68610';
insert into t1sum select 440, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1902-07-17 04:31:30.5944' and '2036-11-22 20:35:45.4';
insert into t1sum select 441, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1923-07-14' and '1926-12-28';
insert into t1sum select 442, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1902' and '1925';
insert into t1sum select 443, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1986-11-25 03:48:08.27' and '2001-10-13 09:47:44.65';
insert into t1sum select 444, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1928' and '1998';
insert into t1sum select 445, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1982-05-10 14:46:47' and '2001-02-01 20:29:49.73710';
insert into t1sum select 446, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2045' and '2105';
insert into t1sum select 447, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1974-07-02 00:53:31.9095' and '1992-03-19 18:50:12.20';
insert into t1sum select 448, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1970-08-06 22:41:48' and '1988-10-04 07:02:40';
insert into t1sum select 449, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '10:52:09.91' and '22:52:59.99999';
insert into t1sum select 450, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2014-04-30 21:58:40.890' and '2080-08-23 01:01:55.409';
insert into t1sum select 451, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1945-02-11 20:18:20.99' and '8119-07-10 21:45:46.14';
insert into t1sum select 452, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2007-12-19 00:40:50' and '2010-05-19 17:25:17';
insert into t1sum select 453, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2033' and '2150';
insert into t1sum select 454, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1905-06-23 00:56:35.563' and '7608-10-31 09:27:16.9';
insert into t1sum select 455, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1968-06-18' and '2077-06-03';
insert into t1sum select 456, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1994-09-05 06:58:11.330' and '2032-11-16 00:04:21.6424';
insert into t1sum select 457, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1996-01-22 16:31:59.89032' and '2069-01-21 06:41:06';
insert into t1sum select 458, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1959' and '2050';
insert into t1sum select 459, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2078-07-04 03:52:55.9' and '1979-10-26 02:36:00';
insert into t1sum select 460, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '08:27:13.935' and '82:25:08.9';
insert into t1sum select 461, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2053-08-15' and '2080-06-29';
insert into t1sum select 462, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-11-13 06:45:59.14' and '2021-12-18 04:39:12.71';
insert into t1sum select 463, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-58:00:20.5597' and '19:19:36.69';
insert into t1sum select 464, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2001-06-30 22:43:50.2322' and '2033-11-14 05:19:50.416';
insert into t1sum select 465, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2051' and '2074';
insert into t1sum select 466, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2001-12-15' and '2003-07-09';
insert into t1sum select 467, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2108' and '2141';
insert into t1sum select 468, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1980-03-09 09:56:56.572' and '2034-06-01 04:45:29.8892';
insert into t1sum select 469, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1944' and '2021';
insert into t1sum select 470, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1929' and '2118';
insert into t1sum select 471, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1969-03-08' and '8708-05-01';
insert into t1sum select 472, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1989-08-03 16:39:31' and '1955-01-19 10:15:52.21508';
insert into t1sum select 473, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1991' and '1999';
insert into t1sum select 474, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2024-01-25 08:01:35.6651' and '2036-06-26 17:27:30.6445';
insert into t1sum select 475, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '2084' and '2100';
insert into t1sum select 476, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-14:44:55.822574' and '07:56:07.39027';
insert into t1sum select 477, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-17:04:31.7' and '-21:16:32';
insert into t1sum select 478, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1912-03-13' and '2073-01-14';
insert into t1sum select 479, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-06:42:34.27' and '-20:33:03.42793';
insert into t1sum select 480, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1997-02-09' and '8268-07-21';
insert into t1sum select 481, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1901' and '2095';
insert into t1sum select 482, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '2036-07-02 19:24:36.56' and '1995-03-17 17:47:05.468868';
insert into t1sum select 483, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-19:59:09.7' and '-72:39:38.89';
insert into t1sum select 484, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '1990-12-03' and '9902-06-07';
insert into t1sum select 485, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1979-01-03 23:05:31.126517' and '2015-12-05 08:59:13';
insert into t1sum select 486, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where c between '2054-07-29' and '2090-08-17';
insert into t1sum select 487, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1970-10-30 03:39:50.422' and '1999-02-15 14:58:10';
insert into t1sum select 488, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2013-02-05 04:05:13' and '2077-03-05 16:35:50.9';
insert into t1sum select 489, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1993-05-07 01:45:52' and '2021-02-04 00:43:28.1';
insert into t1sum select 490, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1137-01-10 18:31:42.42259' and '1918-09-11 15:53:26.712622';
insert into t1sum select 491, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-490:28:00.832557' and '16:45:21';
insert into t1sum select 492, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '07:45:17' and '10:36:21.61';
insert into t1sum select 493, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2029-07-06 03:17:48.9' and '2080-01-19 21:23:33.9999';
insert into t1sum select 494, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2029-11-09 12:57:59.442616' and '2040-03-16 12:02:36.2523';
insert into t1sum select 495, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where b between '1957' and '2089';
insert into t1sum select 496, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where d between '-10:31:38.1' and '-11:39:45.8';
insert into t1sum select 497, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where f between '1980-05-02 01:24:09.4123' and '2007-12-23 06:59:36.713652';
insert into t1sum select 498, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '1928-06-08 15:29:34.2' and '2015-11-23 17:48:44';
insert into t1sum select 499, count(*), sum(crc32(concat(a,b,c,d,e,f))) from t1 where e between '2098-01-14 17:21:38.2' and '5244-12-11 10:01:53.658313';

--enable_query_log

select sum(cnt), sum(crc32(concat(cnt,crc))) from t1sum;
