# This include file contains perl code to remove the environment for testing of startup options 
# with bootstrap.
# Creator: Horst Hunger
# Date:    2012-09-17
#
perl;
use lib "include";
use server_option_test;
fini_bootstrap();
EOF

