# In case force_myisam_default.inc is included then MTR starts the
# server/servers with default_storage_engine=MyISAM for that test
# it does not however check for the presence of availability of
# MyISAM.
